##  Filtering Assets by Type and Status
The integration enables filtering for asset types (subtypes of either Business Asset or Data Asset) to be mapped to your SAP LeanIX workspace, as well as specifying which statuses will be considered. Only assets that have at least one of the selected types are mapped. If no status is chosen, all statuses are considered.
In the Asset Types and Asset Statuses lists, select the options that you need.
